@@ -5,9 +5,11 @@
 #include "../chum/chum.h"  //jammo_get_actor_by_id
 #include "jammo-mentor.h"
 
+static void end_jammo(JammoMentor* mentor, const gchar* speech, gpointer sequencer){
+	printf("Quitted by player\n");
+	clutter_main_quit();
+}
 
 void quitconfirmation_quit_confirmed(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_quit_byebye_fi.ogg", exit, NULL);
-	printf("Quitted by player\n");
-	//exit(0);
+	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_quit_byebye_fi.ogg", end_jammo, NULL);
 }
