@@ -61,6 +61,10 @@ static ClutterScript* config_return_script (gchar* config_file)
 
 ClutterScript* mainScript = NULL;
 ClutterScript* sequencerScript = NULL;
+ClutterScript* startmenuScript = NULL;
+ClutterScript* gamesmenuScript = NULL;
+ClutterScript* communitymenuScript = NULL;
+
 
 /**
  * config_get_configured_actor() returns a ClutterActor according
@@ -122,6 +126,69 @@ ClutterActor* config_get_configured_actor (const gchar *scriptname, gchar* actor
 
 		return actor;
 	}
+	else if (strcmp(scriptname, "startmenu") == 0)
+		{
+			if (startmenuScript == NULL)
+			{
+				buffer=g_strdup_printf("%s/config.json",STARTMENU_DIR);
+				if(!(startmenuScript = config_return_script(buffer)))
+					{
+					fprintf(stderr, "get_configured_actor: Error: Could not find config file.\n");
+					g_free(buffer);
+					return NULL;
+				}
+				g_free(buffer);
+			}
+
+			if(!(actor = CLUTTER_ACTOR(clutter_script_get_object(startmenuScript, actor_name)))) {
+				fprintf(stderr, "get_configured_actor: Error: Could not find %s from config file.\n", actor_name);
+				return NULL;
+			}
+
+			return actor;
+		}
+	else if (strcmp(scriptname, "gamesmenu") == 0)
+			{
+				if (gamesmenuScript == NULL)
+				{
+					buffer=g_strdup_printf("%s/config.json",GAMESMENU_DIR);
+					if(!(gamesmenuScript = config_return_script(buffer)))
+						{
+						fprintf(stderr, "get_configured_actor: Error: Could not find config file.\n");
+						g_free(buffer);
+						return NULL;
+					}
+					g_free(buffer);
+				}
+
+				if(!(actor = CLUTTER_ACTOR(clutter_script_get_object(gamesmenuScript, actor_name)))) {
+					fprintf(stderr, "get_configured_actor: Error: Could not find %s from config file.\n", actor_name);
+					return NULL;
+				}
+
+				return actor;
+			}
+	else if (strcmp(scriptname, "communitymenu") == 0)
+			{
+				if (communitymenuScript == NULL)
+				{
+					buffer=g_strdup_printf("%s/config.json",COMMUNITYMENU_DIR);
+					if(!(communitymenuScript = config_return_script(buffer)))
+						{
+						fprintf(stderr, "get_configured_actor: Error: Could not find config file.\n");
+						g_free(buffer);
+						return NULL;
+					}
+					g_free(buffer);
+				}
+
+				if(!(actor = CLUTTER_ACTOR(clutter_script_get_object(communitymenuScript, actor_name)))) {
+					fprintf(stderr, "get_configured_actor: Error: Could not find %s from config file.\n", actor_name);
+					return NULL;
+				}
+
+				return actor;
+			}
 	else return NULL;
 }
 
